pub struct RangeAssemblerInput {
pub range_id: String,
pub columns: Vec<ColumnInfo>,
pub payloads: Vec<RangeAssemblerPayload>,
pub terminal: RangeTerminal,
}Expand description
All preparation payloads and terminal evidence for one planned range.
Fields
range_id: Stringcolumns: Vec<ColumnInfo>Output schema for row payloads. Aggregate payload schemas are defined by the assembly plan because partial states are not public rows.
payloads: Vec<RangeAssemblerPayload>terminal: RangeTerminalTrait Implementations
Sourceimpl Clone for RangeAssemblerInput
impl Clone for RangeAssemblerInput
Sourcefn clone(&self) -> RangeAssemblerInput
fn clone(&self) -> RangeAssemblerInput
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RangeAssemblerInput
impl Debug for RangeAssemblerInput
Sourceimpl PartialEq for RangeAssemblerInput
impl PartialEq for RangeAssemblerInput
impl StructuralPartialEq for RangeAssemblerInput