pub fn classify(
plan: &LogicalPlan,
table_references: &[TableReference],
) -> RemoteReadClassificationExpand description
Classifies a fully planned statement before routing or transport.
pub fn classify(
plan: &LogicalPlan,
table_references: &[TableReference],
) -> RemoteReadClassificationClassifies a fully planned statement before routing or transport.