pub enum SpillPolicy {
FailFast,
SpillToDisk {
directory: PathBuf,
},
}Expand description
Policy for handling memory-limit crossings.
Variants
FailFast
Return an error immediately when memory usage exceeds the configured limit.
SpillToDisk
Allow the caller to spill buffered state to files in directory.