pub fn is_store_direct_plan(plan: &LogicalPlan) -> boolExpand description
Returns whether a plan requires direct access to the backing KV store.
pub fn is_store_direct_plan(plan: &LogicalPlan) -> boolReturns whether a plan requires direct access to the backing KV store.