SpillMetricsSink

Trait SpillMetricsSink 

pub trait SpillMetricsSink: Send + Sync {
    // Required method
    fn record_spill(&self, bytes: u64, files: u64);
}
Sink for spill metrics emitted by generic streaming helpers.

Required Methods

fn record_spill(&self, bytes: u64, files: u64)

Record the total bytes and file count written by a spill operation.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors