pub enum AggregateMode {
Partial,
Final,
Single,
}Expand description
Aggregate execution mode.
Variants
Partial
Consume raw input rows and output aggregate partial state rows.
Final
Consume partial state rows and output final aggregate values.
Single
Consume raw input rows and output final aggregate values in one pass.