pub fn create_accumulator(
function: &AggregateFunction,
distinct: bool,
) -> Box<dyn Accumulator>Expand description
Create a new accumulator instance for the aggregate function.
pub fn create_accumulator(
function: &AggregateFunction,
distinct: bool,
) -> Box<dyn Accumulator>Create a new accumulator instance for the aggregate function.