merge_exact_aggregate_states

Function merge_exact_aggregate_states 

pub fn merge_exact_aggregate_states(
    aggregates: &[AggregateExpr],
    partial_rows: impl IntoIterator<Item = Vec<Vec<SqlValue>>>,
) -> Result<Vec<SqlValue>>
Merge only aggregate states whose merge rule is proven to preserve the current local SQL result. This is the coordinator-side kernel used by the distributed result assembler after every worker has acknowledged cleanup.