pub struct AggregateIterator<'a> { /* private fields */ }Expand description
Iterator that performs hash-based aggregation over input rows.
Implementations
Sourceimpl<'a> AggregateIterator<'a>
impl<'a> AggregateIterator<'a>
Sourcepub fn new(
input: Box<dyn RowIterator + 'a>,
group_keys: Vec<TypedExpr>,
aggregates: Vec<AggregateExpr>,
having: Option<TypedExpr>,
schema: Vec<ColumnMetadata>,
) -> Self
pub fn new( input: Box<dyn RowIterator + 'a>, group_keys: Vec<TypedExpr>, aggregates: Vec<AggregateExpr>, having: Option<TypedExpr>, schema: Vec<ColumnMetadata>, ) -> Self
Create a new aggregate iterator with the default group limit.
Sourcepub fn with_group_limit(self, limit: usize) -> Self
pub fn with_group_limit(self, limit: usize) -> Self
Override the maximum number of groups allowed during aggregation.
Sourcepub fn with_memory_policy(self, policy: Option<MemoryPolicy>) -> Self
pub fn with_memory_policy(self, policy: Option<MemoryPolicy>) -> Self
Attach a memory policy for enforcing in-flight aggregation limits.