AggregateFunction

Enum AggregateFunction 

pub enum AggregateFunction {
Show 36 variants Count, Sum, Total, Avg, Min, Max, GroupConcat { separator: Option<String>, }, StringAgg { separator: Option<String>, }, PercentileDisc { fraction: f64, }, PercentileCont { fraction: f64, }, QuantileCont { fraction: f64, }, Variance { sample: bool, }, Stddev { sample: bool, }, Covariance { sample: bool, }, Corr, Median, Mode, RegrCount, RegrAvgX, RegrAvgY, RegrSxx, RegrSyy, RegrSxy, RegrSlope, RegrIntercept, RegrR2, AnyValue, First, Last, ArgMin, ArgMax, BitAnd, BitOr, BitXor, BoolAnd, BoolOr,
}
Supported aggregate function types.

Variants



Count



Sum



Total



Avg



Min



Max



GroupConcat

Fields

separator: Option<String>


StringAgg

Fields

separator: Option<String>


PercentileDisc

Ordered-set aggregate PERCENTILE_DISC(fraction) WITHIN GROUP (ORDER BY ...) (issue #148). fraction is validated by the planner to be a literal in [0, 1]. Issue #154 (PERCENTILE_CONT / MODE) extends this enum with sibling variants reusing the same ordered-input path.

Fields

fraction: f64


PercentileCont

Fields

fraction: f64


QuantileCont

Fields

fraction: f64


Variance

Fields

sample: bool


Stddev

Fields

sample: bool


Covariance

Fields

sample: bool


Corr



Median



Mode



RegrCount



RegrAvgX



RegrAvgY



RegrSxx



RegrSyy



RegrSxy



RegrSlope



RegrIntercept



RegrR2



AnyValue



First



Last



ArgMin



ArgMax



BitAnd



BitOr



BitXor



BoolAnd



BoolOr