pub fn plan_statement_for_routing<C: Catalog + ?Sized>(
catalog: &C,
statement: &Statement,
) -> Result<PlannedStatement, PlannerError>Expand description
Plan a parsed statement without executing it, returning SQL-owned routing input.
pub fn plan_statement_for_routing<C: Catalog + ?Sized>(
catalog: &C,
statement: &Statement,
) -> Result<PlannedStatement, PlannerError>Plan a parsed statement without executing it, returning SQL-owned routing input.