pub enum WindowFunction {
RowNumber,
Rank,
DenseRank,
PercentRank,
CumeDist,
Ntile(TypedExpr),
Aggregate(AggregateExpr),
Value(ValueWindowFunction),
Lag(OffsetWindowFunction),
Lead(OffsetWindowFunction),
}Expand description
Function evaluated by a window operator.
Variants
RowNumber
Rank
DenseRank
PercentRank
CumeDist
Ntile(TypedExpr)
Aggregate(AggregateExpr)
Value(ValueWindowFunction)
Lag(OffsetWindowFunction)
Value at an offset before the current row in the whole partition.
Lead(OffsetWindowFunction)
Value at an offset after the current row in the whole partition.