pub struct OffsetWindowFunction {
pub value: TypedExpr,
pub offset: Option<TypedExpr>,
pub default: Option<TypedExpr>,
}Expand description
Arguments shared by the positional LAG and LEAD window functions.
Offset and default expressions are evaluated against the current row. The value expression is evaluated against the addressed partition row. Unlike aggregate windows, these functions do not restrict lookup to the current aggregate frame.
Fields
value: TypedExproffset: Option<TypedExpr>default: Option<TypedExpr>Trait Implementations
Sourceimpl Clone for OffsetWindowFunction
impl Clone for OffsetWindowFunction
Sourcefn clone(&self) -> OffsetWindowFunction
fn clone(&self) -> OffsetWindowFunction
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for OffsetWindowFunction
impl RefUnwindSafe for OffsetWindowFunction
impl Send for OffsetWindowFunction
impl Sync for OffsetWindowFunction
impl Unpin for OffsetWindowFunction
impl UnsafeUnpin for OffsetWindowFunction
impl UnwindSafe for OffsetWindowFunction