pub enum StorageRangeConstraintError {
MissingRangeIdentity,
MissingSchemaManifest,
}Expand description
Validation failure while constructing a mandatory worker constraint.
Variants
MissingRangeIdentity
A range worker cannot operate without a stable route identity.
MissingSchemaManifest
A range worker cannot operate without the pinned schema manifest.